# Muon paper published {small}`2022-02-02`

Muon has been published in Genome Biology {cite}`Bredikhin22`.
Muon is a framework for multimodal data built on top of `AnnData`.

Check out [Muon](https://muon.readthedocs.io/en/latest/) and its datastructure [MuData](https://mudata.readthedocs.io/en/latest/).

# COVID-19 datasets distributed as `h5ad` {small}`2020-04-01`

In a joint initiative, the Wellcome Sanger Institute, the Human Cell Atlas, and the CZI distribute datasets related to COVID-19 via anndata's `h5ad` files: [covid19cellatlas.org](https://www.covid19cellatlas.org/).
